=========
Tutorials
=========

These tutorials will guide you through all the steps of setting up a development
environment and creating a package.

.. toctree::
   :maxdepth: 1

   tutorial/dvlpt_env
   tutorial/pypi
   tutorial/migration
   tutorial/web_tools

Single option tutorials
-----------------------

These tutorials are specific to a single option.

.. toctree::
   :maxdepth: 1

   option/coveralls/coveralls_tutorial
   option/data/data_tutorial
   option/github/github_tutorial
   option/gitlab/gitlab_tutorial
   option/landscape/landscape_tutorial
   option/plugin/plugin_tutorial
   option/pypi/pypi_tutorial
   option/readthedocs/readthedocs_tutorial
   option/requires/requires_tutorial
   option/travis/travis_tutorial
